##  Objective
  * Extract business objectives from the diagram and identify their relationships to initiatives and business contexts.
  * Identify objective elements and how they align with business capabilities and initiatives in the architecture.


YesNo
Send
